# Finmetrics

## About

Finmetrics is a open source python and npm package aimed to help speed up the process of developing financial applications and programs using both platforms. This package contains pre-built classes, methods, and functions, and (future) charts and visualizations.

This package can be used by almost anyone from casual investors to professionals in finance.

## Documentation

We have an in-depth documentation site you can access by clicking the link below: 

[Documentation Page](https://finmetrics-docs.vercel.app)
https:finmetrics-docs.vercel.app


## Installation

To install the python library

```commandline
pip install finmetrics
```

To install the npm library

```commandline
npm install finmetrics
```
